C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_SET_DSPIN    **
C**************************
C
C
CD-Doc:
C DSPIn            SUBROUTINE LDM_SET_DSPIN (VALUE, IERR, ERRSTR)
CD-end
      SUBROUTINE LDM_SET_DSPIN (VALUE, IERR, ERRSTR)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Set value of real parameter DSPIN
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      REAL VALUE
      INTEGER IERR
      CHARACTER*(*) ERRSTR

C  VALUE     (R)   Value for the spindle increment in degrees (any value)
C  IERR      (W)   Error flag =0 OK
C  ERRSTR    (W)   Error description string if error found
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      IERR = 0
      ERRSTR = ' '
      DSPIN = VALUE
      IS_DSPIN = 1
      CH_DSPIN = CH_MASK
      ND_DSPIN = -1000
      RETURN
      END
